@@ -1,3 +1,3 @@
-from . import core
+from . import api
 from . import dataclasses
 from . import gcloud
