@@ -2,8 +2,8 @@ import json
 import base64
 import requests
 from google.cloud import pubsub_v1
-from expressmoney.core import Core
-from expressmoney.dataclasses import Result
+from expressmoney.api import Api
+from expressmoney.dataclasses import Result, Status
 from google.cloud import tasks_v2
 import datetime
 
@@ -60,12 +60,12 @@ class PubSub:
         return message_json.encode('utf-8')
 
 
-class Functions:
+class Functions(Status):
     """Взаимодействие Core c Cloud Functions"""
 
     def __init__(self, endpoint, api):
 
-        self.core = Core(endpoint=endpoint)
+        self.core = Api(endpoint=endpoint)
         self.pubsub = PubSub(project_id='expressmoney', topic_name=endpoint)
         self.api = api
 
@@ -95,7 +95,7 @@ class Functions:
         self._set_event(self.core.retrieve(self.pk))
 
         # Обработка в зависимости от текущего статуса события
-        if self.initial_event.get('status') == Status.NEW:
+        if self.initial_event.get('status') == self.NEW:
 
             # Обнвляю статус на IN_PROCESS
             self.core.update(lookup_field=self.pk, status=Status.IN_PROCESS,
@@ -107,7 +107,7 @@ class Functions:
             # Сохраняю результат
             self.core.update(lookup_field=self.pk, status=result.status, comment=result.comment)
 
-        elif self.initial_event.get('status') == Status.IN_PROCESS:
+        elif self.initial_event.get('status') == self.IN_PROCESS:
 
             # Обрабатываю событие
             result = self._in_process()
@@ -115,7 +115,7 @@ class Functions:
             # Сохраняю результат
             self.core.update(lookup_field=self.pk, status=result.status, comment=result.comment)
 
-        return Status.SUCCESS, 200
+        return self.SUCCESS, 200
 
     def _set_pk(self, pk):
         """pk(primary key) для объекта Event"""
@@ -128,13 +128,13 @@ class Functions:
     def _new(self):
         """Подготовка доменных данных и передача их в сервиса _service_new()"""
 
-        user = Core('user')
-        profile = Core('profile')
+        user = Api('user')
+        profile = Api('profile')
         user_obj = user.retrieve(self.initial_event.get('user'))
         profile_obj = profile.retrieve(self.initial_event.get('user'))
         data = {**user_obj, **profile_obj}
 
-        return Result(Status.SUCCESS, 'Demo result comment in _service_new()')
+        return Result(self.SUCCESS, 'Demo result comment in _service_new()')
 
     def _in_process(self):
         """Подготовка доменных данных и передача их в сервиса _service_in_process()"""
@@ -142,20 +142,20 @@ class Functions:
         raise RuntimeError('Status IN_PROCESS недопустим для Event')
 
 
-class Tasks:
+class Tasks(Status):
     """Работа с Google Cloud Tasks"""
 
     project = 'expressmoney'
     location = 'europe-west1'
     client = tasks_v2.CloudTasksClient()
 
-    def __init__(self, endpoint, in_seconds=None, name=None):
+    def __init__(self, endpoint, queue, in_seconds=None, name=None):
 
         self.endpoint = endpoint
 
-        self.parent = self.client.queue_path(self.project, self.location, queue=endpoint)
+        self.parent = self.client.queue_path(self.project, self.location, queue=queue)
 
-        self.payloads = Core(self.endpoint).list()
+        self.payloads = Api(self.endpoint).list()
 
         self.task = {
             'app_engine_http_request': {
@@ -189,8 +189,8 @@ class Tasks:
             # Prepares task
             task = self.task
             task['app_engine_http_request']['body'] = converted_payload
-            task['app_engine_http_request']['relative_uri'] = '/core/{}/{}/'.format(self.endpoint, payload.get('id'))
+            task['app_engine_http_request']['relative_uri'] = '/{}/{}/'.format(self.endpoint, payload.get('id'))
 
             self.client.create_task(parent=self.parent, task=task)
 
-        return Status.SUCCESS, 200
+        return self.SUCCESS, 200
